@@ -589,6 +589,8 @@ def mid_term_file_classification(input_file, model_name, model_type,
 
     # convert fix-sized flags to segments and classes
     segs, classes = labels_to_segments(labels, mid_step)
+    for i in range(len(segs)):
+        print(segs[i], classes[i])
     segs[-1] = len(signal) / float(sampling_rate)
     # Load grount-truth:
     labels_gt, class_names_gt, accuracy, cm = \
@@ -605,6 +607,7 @@ def load_ground_truth(gt_file, labels, class_names, mid_step, plot_results):
         # load ground truth and class names
         labels_gt, class_names_gt = load_ground_truth_segments(gt_file,
                                                                mid_step)
+
         # map predicted labels to ground truth class names
         # Note: if a predicted label does not belong to the ground truth
         #       classes --> -1
@@ -618,7 +621,8 @@ def load_ground_truth(gt_file, labels, class_names, mid_step, plot_results):
         cm = calculate_confusion_matrix(labels_new, labels_gt, class_names_gt)
 
         accuracy = plot_segmentation_results(labels_new, labels_gt,
-                                        class_names, mid_step, not plot_results)
+                                             class_names_gt, mid_step, 
+                                             not plot_results)
         if accuracy >= 0:
             print("Overall Accuracy: {0:.2f}".format(accuracy))
 
@@ -803,8 +807,7 @@ def silence_removal(signal, sampling_rate, st_win, st_step, smooth_window=0.5,
 
     return seg_limits
 
-
-def speaker_diarization(filename, n_speakers, mid_window=2.0, mid_step=0.1,
+def speaker_diarization(filename, n_speakers, mid_window=1.0, mid_step=0.1,
                         short_window=0.1, lda_dim=5, plot_res=False):
     """
     ARGUMENTS:
@@ -825,40 +828,44 @@ def speaker_diarization(filename, n_speakers, mid_window=2.0, mid_step=0.1,
                             "data/models")
 
     classifier_all, mean_all, std_all, class_names_all, _, _, _, _, _ = \
-        at.load_model_knn(os.path.join(base_dir, "knn_speaker_10"))
+        at.load_model(os.path.join(base_dir, "svm_rbf_speaker_10"))
     classifier_fm, mean_fm, std_fm, class_names_fm, _, _, _, _,  _ = \
-        at.load_model_knn(os.path.join(base_dir, "knn_speaker_male_female"))
+        at.load_model(os.path.join(base_dir, "svm_rbf_speaker_male_female"))
 
-    mid_feats, st_feats, _ = \
+
+#    labels, _, _, _ = mid_term_file_classification(filename, os.path.join(base_dir, "svm_rbf_speaker_10"), "svm_rbf")
+#    print(labels)
+#    labels, _, _, _ = mid_term_file_classification(filename, os.path.join(base_dir, "svm_rbf_speaker_male_female"), "svm_rbf")
+#    print(labels)
+
+    mid_feats, st_feats, a = \
         mtf.mid_feature_extraction(signal, sampling_rate,
                                    mid_window * sampling_rate,
                                    mid_step * sampling_rate,
-                                   round(sampling_rate * short_window),
-                                   round(sampling_rate * short_window * 0.5))
-    
+                                   round(sampling_rate * 0.05),
+                                   round(sampling_rate * 0.05))
+
     mid_term_features = np.zeros((mid_feats.shape[0] + len(class_names_all) +
                                   len(class_names_fm), mid_feats.shape[1]))
     for index in range(mid_feats.shape[1]):
         feature_norm_all = (mid_feats[:, index] - mean_all) / std_all
         feature_norm_fm = (mid_feats[:, index] - mean_fm) / std_fm
-        _, p1 = at.classifier_wrapper(classifier_all, "knn", feature_norm_all)
-        _, p2 = at.classifier_wrapper(classifier_fm, "knn", feature_norm_fm)
+        _, p1 = at.classifier_wrapper(classifier_all, "svm_rbf", feature_norm_all)
+        _, p2 = at.classifier_wrapper(classifier_fm, "svm_rbf", feature_norm_fm)
         start = mid_feats.shape[0]
         end = mid_feats.shape[0] + len(class_names_all)
         mid_term_features[0:mid_feats.shape[0], index] = mid_feats[:, index]
         mid_term_features[start:end, index] = p1 + 1e-4
         mid_term_features[end::, index] = p2 + 1e-4
-#    mid_term_features = mid_term_features[-len(class_names_all)-len(class_names_fm):, :]
     # normalize features:
     scaler = StandardScaler()
-    mid_feats_norm = scaler.fit_transform(mid_feats.T)
-    n_wins = mid_feats.shape[1]
+    mid_feats_norm = scaler.fit_transform(mid_term_features.T)
 
     # remove outliers:
     dist_all = np.sum(distance.squareform(distance.pdist(mid_feats_norm.T)),
                       axis=0)
     m_dist_all = np.mean(dist_all)
-    i_non_outliers = np.nonzero(dist_all < 1.2 * m_dist_all)[0]
+    i_non_outliers = np.nonzero(dist_all < 1.1 * m_dist_all)[0]
 
     # TODO: Combine energy threshold for outlier removal:
     # EnergyMin = np.min(mt_feats[1,:])
@@ -935,12 +942,10 @@ def speaker_diarization(filename, n_speakers, mid_window=2.0, mid_step=0.1,
     
     for speakers in s_range:
         k_means = sklearn.cluster.KMeans(n_clusters=speakers)
-        k_means.fit(mid_feats_norm.T)
-        cls = k_means.labels_        
-        means = k_means.cluster_centers_
-
+        k_means.fit(mid_feats_norm)
+        cls = k_means.labels_ 
         cluster_labels.append(cls)
-        cluster_centers.append(means)
+#        cluster_centers.append(means)
         sil_1 = []; sil_2 = []
         for c in range(speakers):
             # for each speaker (i.e. for each extracted cluster)
@@ -950,7 +955,7 @@ def speaker_diarization(filename, n_speakers, mid_window=2.0, mid_step=0.1,
                 sil_2.append(0.0)
             else:
                 # get subset of feature vectors
-                mt_feats_norm_temp = mid_feats_norm[:, cls == c]
+                mt_feats_norm_temp = mid_feats_norm[cls == c, :]
                 # compute average distance between samples
                 # that belong to the cluster (a values)
                 dist = distance.pdist(mt_feats_norm_temp.T)
@@ -961,9 +966,9 @@ def speaker_diarization(filename, n_speakers, mid_window=2.0, mid_step=0.1,
                     if c2 != c:
                         clust_per_cent_2 = np.nonzero(cls == c2)[0].shape[0] /\
                                            float(len(cls))
-                        mid_features_temp = mid_feats_norm[:, cls == c2]
-                        dist = distance.cdist(mt_feats_norm_temp.T,
-                                              mid_features_temp.T)
+                        mid_features_temp = mid_feats_norm[cls == c2, :]
+                        dist = distance.cdist(mt_feats_norm_temp,
+                                              mid_features_temp)
                         sil_temp.append(np.mean(dist)*(clust_per_cent
                                                        + clust_per_cent_2)/2.0)
                 sil_temp = np.array(sil_temp)
