@@ -806,7 +806,7 @@ def evaluate_regression(features, labels, n_exp, method_name, params):
                       for i in range(n_samples - n_train)]
 
             # train multi-class svms:
-            f_train = np.matrix(f_train)
+            f_train = np.array(f_train)
             if method_name == "svm":
                 classifier, train_err = \
                     train_svm_regression(f_train, l_train, C)
